Rohde & Schwarz SGT100A SIGMA Vector Signal Generator RsSgt SCPI module Version 4.80.0.0016
Module documentation: https://RsSgt.readthedocs.io/

Release Notes:

Version 4.80.0.16
- Added arb_files interface
- Default HwInterface repcap is 0 (empty command suffix)

Version 4.80.0.5
- First released version